/**
* DO NOT EDIT THIS FILE.
* See the following change record for more information,
* https://www.drupal.org/node/2815083
* @preserve
**/
(function (Drupal, drupalSettings) {
  Drupal.behaviors.locate_me = {
    attach: function attach() {
      var messages = new Drupal.Message();
      if ('geolocation' in navigator) {
        var $selector = '[data-target-selector-id]';
        var $buttons = once('locate_me', $selector);
        if ($buttons) {
          $buttons.forEach(function (button) {
            button.addEventListener('click', function () {
              if ('geolocation' in navigator) {
                messages.clear();
                messages.add(Drupal.t('Locating...'));
                Drupal.behaviors.locate_me.target_id = button.getAttribute('data-target-selector-id');
                navigator.geolocation.getCurrentPosition(Drupal.behaviors.locate_me.success, Drupal.behaviors.locate_me.error, {
                  timeout: 5000,
                  enableHighAccuracy: true
                });
              } else {
                messages.clear();
                messages.add(Drupal.t('Geolocation is not supported by this browser.'), {
                  type: 'error'
                });
              }
              return false;
            });
          });
        }
      } else {
        messages.clear();
        messages.add(Drupal.t('Geolocation is not supported by this browser.'), {
          type: 'error'
        });
      }
    },
    success: function success(position) {
      var messages = new Drupal.Message();
      messages.clear();
      var latitude = position.coords.latitude;
      var longitude = position.coords.longitude;
      var baseUrl = drupalSettings.path.baseUrl;
      var providers = drupalSettings.geocode_origin_autocomplete.providers.toString();
      var geocodePath = "".concat(baseUrl, "geocoder/api/reverse_geocode");
      var latLon = encodeURIComponent("".concat(latitude, ",").concat(longitude));
      fetch("".concat(geocodePath, "?latlng=").concat(latLon, "&geocoder=").concat(providers)).then(function (response) {
        return response.json();
      }).then(function (data) {
        var $value = data[0].formatted_address;
        var $selector = "[data-drupal-selector=".concat(Drupal.behaviors.locate_me.target_id, "]");
        var $element = document.querySelector($selector);
        if ($element) {
          $element.value = $value;
        }
      }).catch(function () {
        messages.clear();
        messages.add(Drupal.t('A server error has occurred.'), {
          type: 'error'
        });
      });
    },
    error: function error() {
      var messages = new Drupal.Message();
      messages.clear();
      messages.add(Drupal.t('Locating not possible.'), {
        type: 'error'
      });
    }
  };
})(Drupal, drupalSettings);